==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1JobTemplateSpecFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta1JobTemplateSpecFluentImpl<A extends V1beta1JobTemplateSpecFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1JobTemplateSpecFluent<A>{

    private V1ObjectMetaBuilder metadata;
    private V1JobSpecBuilder spec;

    public V1beta1JobTemplateSpecFluentImpl(){
    }
    public V1beta1JobTemplateSpecFluentImpl(V1beta1JobTemplateSpec instance){
            this.withMetadata(instance.getMetadata());

            this.withSpec(instance.getSpec());

    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public V1ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(V1ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new V1ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new V1ObjectMetaBuilder().build());
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1JobSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public V1JobSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(V1JobSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new V1JobSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> withNewSpecLike(V1JobSpec item){
            return new SpecNestedImpl(item);
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new V1JobSpecBuilder().build());
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(V1JobSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1JobTemplateSpecFluentImpl that = (V1beta1JobTemplateSpecFluentImpl) o;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends V1ObjectMetaFluentImpl<V1beta1JobTemplateSpecFluent.MetadataNested<N>> implements V1beta1JobTemplateSpecFluent.MetadataNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1ObjectMetaBuilder builder;
    
            MetadataNestedImpl(V1ObjectMeta item){
                    this.builder = new V1ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new V1ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1JobTemplateSpecFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends V1JobSpecFluentImpl<V1beta1JobTemplateSpecFluent.SpecNested<N>> implements V1beta1JobTemplateSpecFluent.SpecNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1JobSpecBuilder builder;
    
            SpecNestedImpl(V1JobSpec item){
                    this.builder = new V1JobSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new V1JobSpecBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1JobTemplateSpecFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1JobTemplateSpecFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta1JobTemplateSpecFluentImpl<A extends V1beta1JobTemplateSpecFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1JobTemplateSpecFluent<A>{

    private V1ObjectMetaBuilder metadata;
    private V1JobSpecBuilder spec;

    public V1beta1JobTemplateSpecFluentImpl(){
    }
    public V1beta1JobTemplateSpecFluentImpl(V1beta1JobTemplateSpec instance){
            this.withMetadata(instance.getMetadata());

            this.withSpec(instance.getSpec());

    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public V1ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(V1ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new V1ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new V1ObjectMetaBuilder().build());
    }

    public V1beta1JobTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1JobSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public V1JobSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(V1JobSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new V1JobSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> withNewSpecLike(V1JobSpec item){
            return new SpecNestedImpl(item);
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new V1JobSpecBuilder().build());
    }

    public V1beta1JobTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(V1JobSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1JobTemplateSpecFluentImpl that = (V1beta1JobTemplateSpecFluentImpl) o;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends V1ObjectMetaFluentImpl<V1beta1JobTemplateSpecFluent.MetadataNested<N>> implements V1beta1JobTemplateSpecFluent.MetadataNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1ObjectMetaBuilder builder;
    
            MetadataNestedImpl(V1ObjectMeta item){
                    this.builder = new V1ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new V1ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1JobTemplateSpecFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends V1JobSpecFluentImpl<V1beta1JobTemplateSpecFluent.SpecNested<N>> implements V1beta1JobTemplateSpecFluent.SpecNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1JobSpecBuilder builder;
    
            SpecNestedImpl(V1JobSpec item){
                    this.builder = new V1JobSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new V1JobSpecBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1JobTemplateSpecFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}


}
